==> audiochain-1.1.5-src.tgz: org/audiochain/model/SourceAudioDevice.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.model;

import java.io.IOException;

import org.audiochain.io.AudioDataReader;
import org.audiochain.io.AudioIOException;
import org.audiochain.io.FrameObserver;


public interface SourceAudioDevice extends AudioDevice {
	
	/**
	 * Creates an AudioDataReader. The returned AudioDataReader must be assigned to this AudioDevice instance
	 * in a transient field. The parameter AudioDataReader source should the source for the returned AudioDataReader,
	 * where the AudioData is read from.
	 * 
	 * @param frameObserver optional information for audioDevices, which need to access real time frame position. If this
	 * parameter is null, the audioDevice has to work properly anyway.
	 * 
	 * @return an instance of this AudioDevice specific AudioDataReader implementation.
	 * @throws IOException 
	 */
	public AudioDataReader createAudioDataReader(float frameRate, int sampleSizeInBits, FrameObserver frameObserver) throws IOException;
	
	/**
	 * The length of the audio data that will be produced by this device. If this value is not predictable,
	 * this method should return -1
	 * @return the length of the audio data
	 */
	public long getMaxFrame();
	
	/**
	 * If the device has audio data that can be read at this time, this method return true. If this device has not yet
	 * any data present, it should return false.
	 * @return true, if the data ran be read immediately.
	 */
	public boolean isAudioDataAvailable();
	
	/**
	 * Indicates, if this source device implementation can record audio data.
	 * @return true, if this implementation can capture and record audio data from the input line.
	 */
	public boolean isRecordable();
	
	/**
	 * Returns a {@link Performable} to record or whatever this device is able to.
	 * @return an implementation of {@link Performable}
	 * @throws AudioIOException 
	 */
	public Performable getPerformable() throws AudioIOException;
}

==> audiochain-1.1.6-src.tgz: org/audiochain/model/SourceAudioDevice.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.model;

import java.io.IOException;

import org.audiochain.io.AudioDataReader;
import org.audiochain.io.AudioIOException;
import org.audiochain.io.FrameObserver;


public interface SourceAudioDevice extends AudioDevice {
	
	/**
	 * Creates an AudioDataReader. The returned AudioDataReader must be assigned to this AudioDevice instance
	 * in a transient field.
	 * 
	 * @param frameObserver optional information for audioDevices, which need to access real time frame position. If this
	 * parameter is null, the audioDevice has to work properly anyway.
	 * 
	 * @return an instance of this AudioDevice specific AudioDataReader implementation.
	 * @throws IOException 
	 */
	public AudioDataReader createAudioDataReader(float frameRate, int sampleSizeInBits, FrameObserver frameObserver) throws IOException;
	
	/**
	 * The length of the audio data that will be produced by this device. If this value is not predictable,
	 * this method should return -1
	 * @return the length of the audio data
	 */
	public long getMaxFrame();
	
	/**
	 * If the device has audio data that can be read at this time, this method return true. If this device has not yet
	 * any data present, it should return false.
	 * @return true, if the data ran be read immediately.
	 */
	public boolean isAudioDataAvailable();
	
	/**
	 * Indicates, if this source device implementation can record audio data.
	 * @return true, if this implementation can capture and record audio data from the input line.
	 */
	public boolean isRecordable();
	
	/**
	 * Returns a {@link Performable} to record or whatever this device is able to.
	 * @return an implementation of {@link Performable}
	 * @throws AudioIOException 
	 */
	public Performable getPerformable() throws AudioIOException;
}
